"""
This module contains all exceptions classes for client use.
"""


class MonaExportException(Exception):
    pass


class MonaAuthenticationException(Exception):
    pass


class MonaConfigException(Exception):
    pass


class MonaInitializationException(Exception):
    pass
